<?php

namespace Fastrack\Property;

use SilverStripe\Control\Controller;
use SilverStripe\Control\Director;
use SilverStripe\ORM\DataObject;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;

class BeddingConfiguration extends DataObject implements PermissionProvider
{
	private static $table_name = 'bedding_configuration';

	private static $db = [
		'Title' => 'Varchar(255)',
		'BeddingType' => 'Varchar(255)',
		'Beds' => 'Int'
	];

	private static $has_one = [
		'Room' => Room::class,
	];

	public function CMSEditLink()
	{
		return Controller::join_links([
			$this->Room()->CMSEditLink(),
			'ItemEditForm',
			'field',
			'BeddingConfigurations',
			'item',
			$this->ID,
		]);
	}

	public function WorkflowLink()
	{
		return Controller::join_links([Director::absoluteBaseURL(), $this->CMSEditLink()]);
	}

	public function getCMSFields()
	{
		$fields = parent::getCMSFields();
		$fields->removeByName('Title');
		return $fields;
	}

	public function onBeforeWrite()
	{
		$this->Title = $this->BeddingType;
		parent::onBeforeWrite();
	}

	public function providePermissions()
	{
		$permisions = [
			'MANAGE_BEDDING_CONFIGURATION' => [
				'name' => 'Manage bedding configuration',
				'category' => 'Properties',
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		return Permission::check(['MANAGE_BEDDING_CONFIGURATION']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_BEDDING_CONFIGURATION']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_BEDDING_CONFIGURATION']);
	}

	public function canCreate($member = null, $context = array())
	{
		return Permission::check(['MANAGE_BEDDING_CONFIGURATION']);
	}

}
