<?php

namespace Fastrack\Property;

use SilverStripe\ORM\DataObject;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;

class BookDirectFeature extends DataObject implements PermissionProvider
{
	private static $table_name = 'book_direct_feature';

	private static $db = [
		'Title' => 'Varchar(255)',
		'Excerpt' => 'Text',
		'Key' => 'Varchar(255)',
	];

	private static $many_many = [
		'Features' => Feature::class,
	];

	private static $translate = [
		'Title',
		'Excerpt',
	];

	public function providePermissions()
	{
		$permisions = [
			'MANAGE_BOOK_DIRECT_FEATURES' => [
				'name' => 'Manage book direct features',
				'category' => 'Properties',
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		return Permission::check(['MANAGE_BOOK_DIRECT_FEATURES']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_BOOK_DIRECT_FEATURES']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_BOOK_DIRECT_FEATURES']);
	}

	public function canCreate($member = null, $context = array())
	{
		return Permission::check(['MANAGE_BOOK_DIRECT_FEATURES']);
	}
}
