<?php

namespace Fastrack\Property;

use Fastrack\Gallery\Gallery;
use Fastrack\Utilities\ModelUtilities;
use Fastrack\Utilities\Slug;
use SilverStripe\Control\Controller;
use SilverStripe\Control\Director;
use SilverStripe\ORM\ArrayList;
use SilverStripe\ORM\DataObject;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;
use SilverStripe\Security\Security;

class EventRoom extends DataObject implements PermissionProvider
{
	private static $table_name = 'event_room';

	private static $db = [
		'Title' => 'Varchar(255)',
		'Name' => 'Varchar(255)',
		'Slug' => 'Varchar(255)',
		'NumberOfSpaces' => 'Varchar(255)',
		'NumberOfGuests' => 'Varchar(255)',
		'Size' => 'Varchar(255)',
		'CateringAvailable' => 'Boolean'
	];

	private static $has_one = [
		'Property' => Property::class,
	];

	private static $has_many = [
		'Galleries' => Gallery::class,
	];

	private static $indexes = [
		'Slug' => true,
	];

	private static $translate = [
		'Title',
		'Name',
	];

	public function onBeforeWrite() {
		$this->Title = $this->Name;
		$this->Slug = Slug::generateSlug($this->Name, $this->Slug);
		Gallery::createDefaultGalleries($this);
		parent::onBeforeWrite();
	}

	public function Link()
	{
		$link = new ArrayList([$this->Property()->EventRoomsLink(), $this->Slug]);
		$this->extend('updateLink', $link);
		return Controller::join_links($link->toArray());
	}

	public function CMSEditLink()
	{
		return Controller::join_links([
			$this->Property()->CMSEditLink(),
			'ItemEditForm',
			'field',
			'EventRooms',
			'item',
			$this->ID,
		]);
	}

	public function WorkflowLink()
	{
		return Controller::join_links([Director::absoluteBaseURL(), $this->CMSEditLink()]);
	}

	public function providePermissions()
	{
		$permisions = [
			'MANAGE_EVENT_ROOMS' => [
				'name' => 'Manage event rooms',
				'category' => 'Properties',
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		if (!$member) {
			if (!Security::getCurrentUser()) {
				return $this->Status === 'Disabled' ? false : true;
			}
		}
		return Permission::check(['MANAGE_EVENT_ROOMS']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_EVENT_ROOMS']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_EVENT_ROOMS']);
	}

	public function canCreate($member = null, $context = array())
	{
		return Permission::check(['MANAGE_EVENT_ROOMS']);
	}

	public function AbsoluteLink()
	{
		return Director::absoluteURL($this->Link());
	}

	public function getCMSFields()
	{
		$fields = parent::getCMSFields();
		ModelUtilities::hideHasOneFields($this, $fields);
		ModelUtilities::hideFields($this, $fields);
		$fields->removeByName('Title');
		return $fields;
	}

	public function useInheritedWorkflow()
	{
		return true;
	}

	public function workflowParent()
	{
		return $this->Property();
	}

}
