<?php

namespace Fastrack\Property;

use Fastrack\Gallery\Gallery;
use Fastrack\Utilities\ModelUtilities;
use SilverStripe\Assets\Image;
use SilverStripe\Control\Controller;
use SilverStripe\Control\Director;
use SilverStripe\ORM\ArrayList;
use SilverStripe\ORM\DataObject;
use SilverStripe\Assets\File;
use SilverStripe\Security\Permission;
use SilverStripe\Security\PermissionProvider;
use SilverStripe\Security\Security;

/**
 * @property string Title
 * @property string Name
 */
class Restaurant extends DataObject implements PermissionProvider
{
	private static $table_name = 'restaurant';

	private static $db = [
		'Title' => 'Varchar(255)',
		'Name' => 'Varchar(255)'
	];

	private static $has_one = [
		'Property' => Property::class,
		'File1' => File::class,
		'File2' => File::class,
		'File3' => File::class,
	];

	private static $has_many = [
		'Galleries' => Gallery::class,
	];

	private static $owns = [
		'File1',
		'File2',
		'File3',
	];

	private static $translate = [
		'Title',
		'Name',
	];

	protected function onBeforeWrite()
	{
		$this->Title = $this->Name;
		Gallery::createDefaultGalleries($this);
		parent::onBeforeWrite();
	}

	public function getCMSFields()
	{
		$fields = parent::getCMSFields();
		$fields->removeByName('Title');
		ModelUtilities::hideFields($this, $fields);
		return $fields;
	}

	public function Link()
	{
		$link = new ArrayList([$this->Property()->RestaurantLink(), $this->Slug]);
		$this->extend('updateLink', $link);
		return Controller::join_links($link->toArray());
	}

	public function CMSEditLink()
	{
		return Controller::join_links([
			$this->Property()->CMSEditLink(),
			'ItemEditForm',
			'field',
			'Restaurants',
			'item',
			$this->ID,
		]);
	}

	public function WorkflowLink()
	{
		return Controller::join_links([Director::absoluteBaseURL(), $this->CMSEditLink()]);
	}

	public function providePermissions()
	{
		$permisions = [
			'MANAGE_RESTAURANTS' => [
				'name' => 'Manage restaurants',
				'category' => 'Properties',
			],
		];
		$this->extend('updatePermisions', $permisions);
		return $permisions;
	}

	public function canView($member = null)
	{
		if (!$member) {
			if (!Security::getCurrentUser()) {
				return $this->Status === 'Disabled' ? false : true;
			}
		}
		return Permission::check(['MANAGE_RESTAURANTS']);
	}

	public function canEdit($member = null)
	{
		return Permission::check(['MANAGE_RESTAURANTS']);
	}

	public function canDelete($member = null)
	{
		return Permission::check(['MANAGE_RESTAURANTS']);
	}

	public function canCreate($member = null, $context = array())
	{
		return Permission::check(['MANAGE_RESTAURANTS']);
	}

	public function useInheritedWorkflow()
	{
		return true;
	}

	public function workflowParent()
	{
		return $this->Property();
	}
}
